@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::Author::BBYRD;
 
-our $VERSION = '0.99'; # VERSION
+our $VERSION = '1.00'; # VERSION
 # ABSTRACT: DZIL Author Bundle for BBYRD
 
 use sanity;
@@ -8,7 +8,7 @@ use Moose;
 
 with 'Dist::Zilla::Role::PluginBundle::Merged' => {
    mv_plugins => [ qw(
-      Git::GatherDir OurPkgVersion PodWeaver Test::ReportPrereqs Test::Compile
+      Git::GatherDir OurPkgVersion PodWeaver Test::ReportPrereqs Test::Compile NoTabsTests
       PruneCruft @Prereqs CheckPrereqsIndexed MetaNoIndex CopyFilesFromBuild
       Git::CheckFor::CorrectBranch @Git TravisYML
    ) ],
@@ -46,10 +46,16 @@ sub configure {
       #
       # ; Extra file creation
       # [GitFmtChanges]
+      # log_format = [%h]%n* Author: %an <%ae>%n* Date:   %ai (%ar)%n%n%B
+      #
+      $self->config_short_merge('GitFmtChanges', {
+         log_format => '[%h]%n* Author: %an <%ae>%n* Date:   %ai (%ar)%n%n%B',
+      }),
+
       # [ManifestSkip]
       # [Manifest]
       # [License]
-      qw( PruneCruft GitFmtChanges ManifestSkip Manifest License ),
+      qw( PruneCruft ManifestSkip Manifest License ),
 
       # [ReadmeAnyFromPod / ReadmePodInRoot]    ; Pod README for Root (for GitHub, etc.)
       # [ReadmeAnyFromPod / ReadmeTextInBuild]  ; Text README for Build
@@ -81,6 +87,9 @@ sub configure {
       $self->config_short_merge('Test::EOL', { trailing_whitespace => 0 }),
 
       #
+      # [Test::CPAN::Changes]
+      $self->config_short_merge('Test::CPAN::Changes', { changelog => 'CHANGES' }),
+
       # [Test::CPAN::Meta::JSON]
       # [Test::CheckDeps]
       # [Test::Portability]
@@ -123,12 +132,12 @@ sub configure {
       $self->config_short_merge('MetaProvides::Package', { meta_noindex => 1 }),
 
       #
-      # [MetaResourcesFromGit]
-      # x_irc          = irc://irc.perl.org/#distzilla
-      # bugtracker.web = https://github.com/%a/%r/issues
-      [MetaResourcesFromGit => {
-         x_irc            => (exists $self->payload->{x_irc} ? $self->payload->{x_irc} : 'irc://irc.perl.org/#distzilla'),
-         'bugtracker.web' => 'https://github.com/%a/%r/issues',
+      # [GithubMeta]
+      # issues = 1
+      # user   = SineSwiper
+      [GithubMeta => {
+         issues => 1,
+         user   => 'SineSwiper',
       }],
 
       #
@@ -208,7 +217,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -238,6 +247,8 @@ Dist::Zilla::PluginBundle::Author::BBYRD - DZIL Author Bundle for BBYRD
  
     ; Extra file creation
     [GitFmtChanges]
+    log_format = [%h]%n* Author: %an <%ae>%n* Date:   %ai (%ar)%n%n%B
+ 
     [ManifestSkip]
     [Manifest]
     [License]
@@ -294,9 +305,9 @@ Dist::Zilla::PluginBundle::Author::BBYRD - DZIL Author Bundle for BBYRD
     [MetaProvides::Package]
     meta_noindex = 1        ; respect prior no_index directives
  
-    [MetaResourcesFromGit]
-    x_irc          = irc://irc.perl.org/#distzilla
-    bugtracker.web = https://github.com/%a/%r/issues
+    [GithubMeta]
+    issues = 1
+    user   = SineSwiper
  
     [ContributorsFromGit]
  
@@ -385,7 +396,7 @@ in your own C<<< dist.ini >>> andE<sol>or Author bundle.
 
 =head1 AVAILABILITY
 
-The project homepage is L<https://github.com/SineSwiper/Dist-Zilla-PluginBundle-Author-BBYRD/wiki>.
+The project homepage is L<https://github.com/SineSwiper/Dist-Zilla-PluginBundle-Author-BBYRD>.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
@@ -422,7 +433,7 @@ Brendan Byrd <BBYRD@CPAN.org>
 
 =head1 CONTRIBUTOR
 
-Brendan Byrd <bbyrd@cpan.org>
+Sergey Romanov <complefor@rambler.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
